( cd usr/bin ; rm -rf ant )
( cd usr/bin ; ln -sf /usr/share/ant/bin/ant ant )
( cd usr/bin ; rm -rf antRun )
( cd usr/bin ; ln -sf /usr/share/ant/bin/antRun antRun )
( cd usr/bin ; rm -rf antRun.pl )
( cd usr/bin ; ln -sf /usr/share/ant/bin/antRun.pl antRun.pl )
( cd usr/bin ; rm -rf runant.pl )
( cd usr/bin ; ln -sf /usr/share/ant/bin/runant.pl runant.pl )
( cd usr/bin ; rm -rf runant.py )
( cd usr/bin ; ln -sf /usr/share/ant/bin/runant.py runant.py )
( cd usr/share/java ; rm -rf ant-antlr.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-antlr.jar ant-antlr.jar )
( cd usr/share/java ; rm -rf ant-apache-bcel.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-apache-bcel.jar ant-apache-bcel.jar )
( cd usr/share/java ; rm -rf ant-apache-bsf.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-apache-bsf.jar ant-apache-bsf.jar )
( cd usr/share/java ; rm -rf ant-apache-log4j.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-apache-log4j.jar ant-apache-log4j.jar )
( cd usr/share/java ; rm -rf ant-apache-oro.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-apache-oro.jar ant-apache-oro.jar )
( cd usr/share/java ; rm -rf ant-apache-regexp.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-apache-regexp.jar ant-apache-regexp.jar )
( cd usr/share/java ; rm -rf ant-apache-resolver.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-apache-resolver.jar ant-apache-resolver.jar )
( cd usr/share/java ; rm -rf ant-apache-xalan2.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-apache-xalan2.jar ant-apache-xalan2.jar )
( cd usr/share/java ; rm -rf ant-commons-logging.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-commons-logging.jar ant-commons-logging.jar )
( cd usr/share/java ; rm -rf ant-commons-net.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-commons-net.jar ant-commons-net.jar )
( cd usr/share/java ; rm -rf ant-imageio.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-imageio.jar ant-imageio.jar )
( cd usr/share/java ; rm -rf ant-jai.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-jai.jar ant-jai.jar )
( cd usr/share/java ; rm -rf ant-jakartamail.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-jakartamail.jar ant-jakartamail.jar )
( cd usr/share/java ; rm -rf ant-javamail.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-javamail.jar ant-javamail.jar )
( cd usr/share/java ; rm -rf ant-jdepend.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-jdepend.jar ant-jdepend.jar )
( cd usr/share/java ; rm -rf ant-jmf.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-jmf.jar ant-jmf.jar )
( cd usr/share/java ; rm -rf ant-jsch.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-jsch.jar ant-jsch.jar )
( cd usr/share/java ; rm -rf ant-junit.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-junit.jar ant-junit.jar )
( cd usr/share/java ; rm -rf ant-junit4.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-junit4.jar ant-junit4.jar )
( cd usr/share/java ; rm -rf ant-junitlauncher.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-junitlauncher.jar ant-junitlauncher.jar )
( cd usr/share/java ; rm -rf ant-launcher.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-launcher.jar ant-launcher.jar )
( cd usr/share/java ; rm -rf ant-netrexx.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-netrexx.jar ant-netrexx.jar )
( cd usr/share/java ; rm -rf ant-swing.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-swing.jar ant-swing.jar )
( cd usr/share/java ; rm -rf ant-testutil.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-testutil.jar ant-testutil.jar )
( cd usr/share/java ; rm -rf ant-xz.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant-xz.jar ant-xz.jar )
( cd usr/share/java ; rm -rf ant.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/ant.jar ant.jar )
